@@ -48,6 +48,26 @@
         <source>Optional customization</source>
         <translation>Προαιρετική παραμετροποίηση</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="65"/>
+        <source>Release version:</source>
+        <translation>Έκδοση:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="79"/>
+        <source>Boot options:</source>
+        <translation>Ρυθμίσεις φορτωτή εκκίνησης:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="86"/>
+        <source>Live kernel:</source>
+        <translation>Ενεργός πυρήνας:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="93"/>
+        <source>Project name:</source>
+        <translation>Όνομα προϊόντος:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="100"/>
         <source>Release date:</source>
@@ -58,30 +78,6 @@
         <source>Release codename:</source>
         <translation>Κωδικό όνομα έκδοσης:</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="86"/>
-        <source>Live kernel:</source>
-        <translation>Ενεργός πυρήνας:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="79"/>
-        <source>Boot options:</source>
-        <translation>Ρυθμίσεις φορτωτή εκκίνησης:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="65"/>
-        <source>Release version:</source>
-        <translation>Έκδοση:</translation>
-    </message>
-    <message>
-        <source>Change live kernel</source>
-        <translation type="vanished">Αλλαγή ενεργού πυρήνα</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="93"/>
-        <source>Project name:</source>
-        <translation>Όνομα προϊόντος:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="133"/>
         <source>Current date</source>
@@ -455,10 +451,6 @@
         <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
         <translation>Το πρόγραμμα θα σταματήσει τώρα για να σας επιτρέψει να επεξεργαστείτε αρχεία στον κατάλογο εργασίας σας. Επιλέξτε Ναι για να επεξεργαστείτε το μενού του φορτωτή εκκίνησης ή Όχι για να παρακάμψετε αυτό το βήμα και να συνεχίσετε.</translation>
     </message>
-    <message>
-        <source>Select kernel</source>
-        <translation type="vanished">Επιλογή πυρήνα</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="593"/>
         <source>About %1</source>
