@@ -48,6 +48,26 @@
         <source>Optional customization</source>
         <translation>Personalizzazione opzionale</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="65"/>
+        <source>Release version:</source>
+        <translation>Versione del rilascio:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="79"/>
+        <source>Boot options:</source>
+        <translation>Opzioni di avvio:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="86"/>
+        <source>Live kernel:</source>
+        <translation>Kernel live:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="93"/>
+        <source>Project name:</source>
+        <translation>Nome del progetto:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="100"/>
         <source>Release date:</source>
@@ -58,30 +78,6 @@
         <source>Release codename:</source>
         <translation>Nome in codice del rilascio:</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="86"/>
-        <source>Live kernel:</source>
-        <translation>Kernel live:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="79"/>
-        <source>Boot options:</source>
-        <translation>Opzioni di avvio:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="65"/>
-        <source>Release version:</source>
-        <translation>Versione del rilascio:</translation>
-    </message>
-    <message>
-        <source>Change live kernel</source>
-        <translation type="vanished">Cambia il kernel live</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="93"/>
-        <source>Project name:</source>
-        <translation>Nome del progetto:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="133"/>
         <source>Current date</source>
@@ -455,10 +451,6 @@ Se necessario, puoi creare più spazio disponibile rimuovendo istantanee precede
         <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
         <translation>Il programma ora andrà in pausa per permetterti di editare alcuni files nella directory di lavoro. Seleziona Yes per editare il menù del boot o seleziona No per bypassare questa fase e continuare a creare la snapshot.</translation>
     </message>
-    <message>
-        <source>Select kernel</source>
-        <translation type="vanished">Seleziona kernel</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="593"/>
         <source>About %1</source>
