@@ -48,6 +48,26 @@
         <source>Optional customization</source>
         <translation>Optioneel maatwerk</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="65"/>
+        <source>Release version:</source>
+        <translation>Releaseversie:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="79"/>
+        <source>Boot options:</source>
+        <translation>Opstartopties:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="86"/>
+        <source>Live kernel:</source>
+        <translation>Live kernel:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="93"/>
+        <source>Project name:</source>
+        <translation>Naam project:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="100"/>
         <source>Release date:</source>
@@ -58,30 +78,6 @@
         <source>Release codename:</source>
         <translation>Codenaam release:</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="86"/>
-        <source>Live kernel:</source>
-        <translation>Live kernel:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="79"/>
-        <source>Boot options:</source>
-        <translation>Opstartopties:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="65"/>
-        <source>Release version:</source>
-        <translation>Releaseversie:</translation>
-    </message>
-    <message>
-        <source>Change live kernel</source>
-        <translation type="vanished">Live kernel wijzigen</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="93"/>
-        <source>Project name:</source>
-        <translation>Naam project:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="133"/>
         <source>Current date</source>
@@ -455,10 +451,6 @@
         <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
         <translation>Het programma zal nu pauzeren om u in staat te stellen bestanden aan te passen in de werk folder. Selecteer Ja om het opstartmenu aan te passen of selecteer Nee om deze stap over te slaan en door te gaan met het creëren van het snapshot.</translation>
     </message>
-    <message>
-        <source>Select kernel</source>
-        <translation type="vanished">Select kernel</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="593"/>
         <source>About %1</source>
