@@ -48,6 +48,26 @@
         <source>Optional customization</source>
         <translation>Дополнительная настройка</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="65"/>
+        <source>Release version:</source>
+        <translation>Версия выпуска:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="79"/>
+        <source>Boot options:</source>
+        <translation>Параметры загрузки:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="86"/>
+        <source>Live kernel:</source>
+        <translation>Загружаемое ядро:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="93"/>
+        <source>Project name:</source>
+        <translation>Имя проекта:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="100"/>
         <source>Release date:</source>
@@ -58,30 +78,6 @@
         <source>Release codename:</source>
         <translation>Кодовое имя выпуска:</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="86"/>
-        <source>Live kernel:</source>
-        <translation>Загружаемое ядро:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="79"/>
-        <source>Boot options:</source>
-        <translation>Параметры загрузки:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="65"/>
-        <source>Release version:</source>
-        <translation>Версия выпуска:</translation>
-    </message>
-    <message>
-        <source>Change live kernel</source>
-        <translation type="vanished">Сменить загружаемое ядро</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="93"/>
-        <source>Project name:</source>
-        <translation>Имя проекта:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="133"/>
         <source>Current date</source>
@@ -457,10 +453,6 @@
         <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
         <translation>Теперь программа будет приостановлена, чтобы позволить вам править файлы в рабочем каталоге. Выберите Да, чтобы изменить меню загрузки, или выберите Нет, чтобы пропустить этот шаг и продолжить создание образа.</translation>
     </message>
-    <message>
-        <source>Select kernel</source>
-        <translation type="vanished">Выбор ядра</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="593"/>
         <source>About %1</source>
